@@ -208,6 +208,10 @@ class JsonableAnswer(Answer):
         return super().__class_getitem__(modifier)
 
 
+class WrappedAnswerBody:
+    pass
+
+
 class WrappedAnswer(JsonableAnswer):
     def __init__(self, payload: Any = Nothing, status: HttpStatusCode = HttpStatusCode.OK,
                  headers: Optional[Dict[str, str]] = None, charset: Charset = Charset.UTF8) -> None:
@@ -221,7 +225,7 @@ class WrappedAnswer(JsonableAnswer):
         if type_ not in (None, type[None]):
             attribute_key_to_type["result"] = type_or_annotated
         new_type_name = prepare_class_name([type_or_annotated],  "Wrapped")
-        return create_dataclass(new_type_name, [], attribute_key_to_type)
+        return create_dataclass(new_type_name, [WrappedAnswerBody], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
         if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
