@@ -11,21 +11,22 @@ from typing import Any, Optional
 from urllib.parse import parse_qsl
 
 import aiohttp.web_request
+from multidict import CIMultiDictProxy
 
 from http_tools.charset import Charset
 from http_tools.mime_types import ContentType
-from http_tools.multipart_form_data import parse_multipart_form_data
+from http_tools.multipart_form_data import parse_multipart_form_data, BodyPart
 from http_tools.request_metadata import RequestMetadata
-from http_tools.parse_query_components import parse_query_components
 
 
 @dataclass
 class IncomingRequest:
     url_query_key_to_value: dict[str, str]
     path_match_key_to_value: dict[str, str]
-    parsed_body: Optional[dict[str, Any]]
+    parsed_body: dict[str, Any] | list[Any] | str | float | int | bool | None | CIMultiDictProxy[BodyPart]
     key_value_params: dict[str, Any]
     metadata: RequestMetadata
+    request: aiohttp.web_request.Request
     payload: Optional[bytes] = field(repr=False, default=None)
 
     @property
@@ -48,7 +49,7 @@ async def request_from_web_request(web_request: aiohttp.web_request.Request) ->
         header_name_to_value=header_name_to_value, url=web_request.url
     )
 
-    url_query = parse_query_components(dict(**web_request.rel_url.query))
+    url_query = dict(**web_request.rel_url.query)
     path_match = dict(**web_request.match_info)
     parsed_body = None
 
@@ -70,5 +71,5 @@ async def request_from_web_request(web_request: aiohttp.web_request.Request) ->
     payload = await web_request.read()
     return IncomingRequest(
         url_query_key_to_value=url_query, path_match_key_to_value=path_match, parsed_body=parsed_body,
-        key_value_params=key_value_params, metadata=request_metadata, payload=payload
+        key_value_params=key_value_params, metadata=request_metadata, payload=payload, request=web_request
     )
